@@ -47,4 +47,16 @@ xlab <- function(label) {
 }
 ylab <- function(label) {
   labs(y = label)
+}
+
+# Convert aesthetic mapping into text labels
+# This is used by ggplot and + to ensure consistent label formatting
+# 
+# @keyword internal
+make_labels <- function(mapping) {
+  remove_dots <- function(x) {
+    gsub("\\.\\.([a-zA-z._]+)\\.\\.", "\\1", x)
+  }
+  
+  lapply(mapping, function(x) remove_dots(deparse(x)))
 }
\ No newline at end of file
